from django.urls import reverse

import pytest
from rest_framework.test import APIClient
from rest_framework import status


@pytest.fixture
def client():
    return APIClient()


@pytest.fixture
def valid_data():
    return {'signer_name': 'Гвидыч', 'signer_surname': 'Ванросыч', 'signer_email': 'robogop2510@gmail.com'}


@pytest.fixture
def invalid_data():
    return {'signer_name': 'Чебурашка', 'signer_surname': 'Генадьева'}


@pytest.fixture
def expected_data():
    return {'id': 1, 'signer_name': 'Гвидыч', 'signer_surname': 'Ванросыч', 'signer_email': 'robogop2510@gmail.com',
            'status': 'Документ отправлен на подпись, проверьте Вашу почту'}


def test_index_view_redirects_to_send_email(client):
    response = client.get(reverse('index'))
    assert response.status_code == status.HTTP_302_FOUND
    assert response.url == reverse('send_email')


def test_get_send_document_view(client):
    response = client.get(reverse('send_email'))
    assert response.status_code == status.HTTP_200_OK
    assert 'index.html' in response.template_name


@pytest.mark.django_db
def test_post_valid_data(client, valid_data, expected_data):
    response = client.post(reverse('send_email'), valid_data)
    assert response.status_code == status.HTTP_200_OK
    assert response.data == expected_data


@pytest.mark.django_db
def test_post_invalid_data(client, invalid_data):
    response = client.post(reverse('send_email'), invalid_data)
    assert response.status_code == status.HTTP_400_BAD_REQUEST
    assert response.data == {'error': 'Bad Request', 'description': 'Введенные Вами данные не валидны'}
