from http.client import HTTPException

from django.shortcuts import redirect, render
from rest_framework.renderers import TemplateHTMLRenderer
from rest_framework.response import Response
from rest_framework.views import APIView

from api.models import StatusChoices, SignerInfo
from api.serializers import DocumentNDASerializer
from api.services import send_docusign_email


def index_view(request):
    return redirect('send_email')


class SendDocumentView(APIView):
    renderer_classes = [TemplateHTMLRenderer]
    template_name = 'index.html'

    def get(self, request):
        return Response(template_name=self.template_name, status=200)

    def post(self, request):
        serializer = DocumentNDASerializer(data=request.data)
        if serializer.is_valid():
            signer = serializer.save()
            try:
                send_docusign_email()
                signer.status = StatusChoices.RESOLVE
                signer.save()
                return Response(status=200, data=serializer.data)
            except HTTPException as e:
                signer.status = StatusChoices.REJECT
                signer.save()
                return Response({'error': e, 'signer': signer}, status=503)
        return Response({'error': 'Bad Request', 'description': 'Введенные Вами данные не валидны'}, status=400)


def view_status(request):
    signer = SignerInfo.objects.last()
    if signer.status == StatusChoices.REJECT:
        data = {'signer': signer, 'status': 'fail'}
    elif signer.status == StatusChoices.RESOLVE:
        data = {'signer': signer, 'status': 'success'}
    else:
        data = {'signer': signer, 'status': 'default'}
    return render(request, 'status.html', context={'data': data}, status=200)
